#
# spec file for package netcfg
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           netcfg
Version:        11.5
Release:        30.3
Summary:        Network Configuration Files in /etc
License:        BSD-3-Clause
Group:          System/Base
Source0:        defaultdomain
Source1:        exports
Source2:        ftpusers
Source3:        host.conf
Source4:        hosts
Source5:        hosts.allow
Source6:        hosts.deny
Source7:        hosts.equiv
Source8:        hosts.lpd
Source9:        networks
Source10:       protocols
Source11:       services.bz2
Source12:       hostname
Source13:       aliases
Source14:       ethers
Source15:       netgroup
Source16:       COPYING
Source100:      services-compare.pl
Source101:      services-compare.sh
Source102:      services-create.pl
Source103:      services_UPDATING
Patch0:         services-suse.diff
# FIXME: use proper Requires(pre/post/preun/...)
PreReq:         aaa_base
PreReq:         coreutils
PreReq:         permissions
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
All of the basic configuration files for the network programs including
%{_sysconfdir}/aliases, %{_sysconfdir}/protocols, and %{_sysconfdir}/services.

These are often used by network routines in the C library and therefore
must be installed for all network programs.

%prep

%build
cp %{SOURCE16} .

%install
mkdir -p %{buildroot}/etc
for i in hostname aliases defaultdomain exports ftpusers host.conf hosts hosts.allow hosts.deny hosts.equiv hosts.lpd netgroup networks protocols services.bz2 ethers; do
  install $RPM_SOURCE_DIR/$i %{buildroot}/etc
done
bunzip2 %{buildroot}%{_sysconfdir}/services.bz2
patch -p0 %{buildroot}%{_sysconfdir}/services < $RPM_SOURCE_DIR/services-suse.diff
rm -f %{buildroot}%{_sysconfdir}/services.orig
ln -s %{_sysconfdir}/hostname %{buildroot}%{_sysconfdir}/HOSTNAME

%pre
if [ "0$1" -ge "2" ]; then
# If we have a /etc/netgroup.rpmsave and no /etc/netgroup, copy
# /etc/netgroup.rpmsave and use it later instead of the new one.
   if [ -f %{_sysconfdir}/netgroup.rpmsave -a ! -e %{_sysconfdir}/netgroup ]; then
      cp %{_sysconfdir}/netgroup.rpmsave %{_sysconfdir}/...netgroup.new.rpmnew
   fi
fi
#/etc/HOSTNAME renamed to /etc/hostname [bnc#858908]
#On Tue, Jun 10, 2014 at 03:23:00PM +0200, Frederic Crozat wrote:
#> So, it means netcfg should have a %pre which check if /etc/HOSTNAME is a
#> filename (and not a symlink) and in that case, rename the file
#> to /etc/hostname. This should ensure /etc/HOSTNAME is properly created
#> by RPM.
if [ "0$1" -ge "2" ]; then
  if [ -f /etc/HOSTNAME -a ! -L /etc/HOSTNAME ]; then
    if [ -f /etc/hostname ]; then
      mv /etc/hostname /etc/hostname.rpmsave
    fi
    ln -f /etc/HOSTNAME /etc/HOSTNAME.rpmsave
    rm /etc/HOSTNAME
  fi
fi

%post
test -f etc/defaultdomain.rpmnew -a ! -s etc/defaultdomain.rpmnew && rm -f etc/defaultdomain.rpmnew
if [ -f etc/...netgroup.new.rpmnew ]; then
  test ! -f etc/netgroup.rpmnew && cp etc/netgroup etc/netgroup.rpmnew
  mv etc/...netgroup.new.rpmnew etc/netgroup
fi
if [ -f /etc/HOSTNAME.rpmsave -a ! -L /etc/HOSTNAME.rpmsave ]; then
  cp -a /etc/HOSTNAME.rpmsave /etc/hostname
fi
exit 0

%files
%defattr(644,root,root,755)
%verify(not md5 size mtime) %config(noreplace) %{_sysconfdir}/hostname
/etc/HOSTNAME
%verify(not md5 size mtime) %config(noreplace) %{_sysconfdir}/aliases
%verify(not md5 size mtime) %config(noreplace) %{_sysconfdir}/defaultdomain
%verify(not md5 size mtime) %config(noreplace) %{_sysconfdir}/ethers
%verify(not md5 size mtime) %config(noreplace) %{_sysconfdir}/exports
%verify(not md5 size mtime) %config(noreplace) %{_sysconfdir}/ftpusers
%config(noreplace) %{_sysconfdir}/host.conf
%verify(not md5 size mtime) %config(noreplace) %{_sysconfdir}/hosts
%verify(not md5 size mtime) %config(noreplace) %{_sysconfdir}/hosts.allow
%verify(not md5 size mtime) %config(noreplace) %{_sysconfdir}/hosts.deny
%verify(not md5 size mtime) %config(noreplace) %{_sysconfdir}/hosts.equiv
%verify(not md5 size mtime) %config(noreplace) %{_sysconfdir}/hosts.lpd
%config(noreplace) %{_sysconfdir}/netgroup
%config(noreplace) %{_sysconfdir}/networks
%config(noreplace) %{_sysconfdir}/protocols
%config(noreplace) %{_sysconfdir}/services
%doc COPYING

%changelog
* Tue Mar  7 2017 tchvatal@suse.com
- Update script to generage services to use UTF8 by default bsc#1028305
- Update the services list with latest content
* Tue Jan  5 2016 tchvatal@suse.com
- Repack services.bz2 with latest from upstream and adjust the script
  to not add all the names+emails at the bottom bnc#959693
* Thu Oct  8 2015 tchvatal@suse.com
- Use linux.suse instead linux.site bnc#948531
* Fri Jul 25 2014 pgajdos@suse.com
- resolve some update scenarios [bnc#883999], [bnc#886443] (private)
  with regard to /etc/HOSTNAME -> /etc/hostname change
* Wed Jun 11 2014 pgajdos@suse.com
- move /etc/HOSTNAME to /etc/hostname during update
* Wed Jun  4 2014 pgajdos@suse.com
- HOSTNAME renamed to hostname [bnc#858908]
* Thu Feb  6 2014 pgajdos@suse.com
- added helper scripts and doc for creating services file to
  Sources
* Tue Oct 29 2013 pgajdos@suse.com
- /etc/protocols: assign 4 to ipv4 instead of ip to correspond with
  IANA [bnc#843511] (internal)
* Thu Aug 22 2013 pgajdos@suse.com
- updated to newer (not newest) version of IANA assignments
  [bnc#831522], [bnc#731391] (both internal)
* Wed Jun  5 2013 pgajdos@suse.com
- services: map sieve to 4190 instead of 2000 as upstream (IANA)
  does
* Mon Mar  7 2011 ro@suse.de
- bump version to 11.5
* Thu Mar  3 2011 pgajdos@suse.cz
- added COPYING file (cfarrell@suse.de)
* Thu Nov  4 2010 pgajdos@suse.cz
- reverted rquotad port assigment [bnc#637382]
  * modified services-suse.diff back to previous state
* Thu Oct 21 2010 pgajdos@suse.cz
- assigned port 4003 to rquotad [bnc#637382]
  * modified services-suse.diff
* Thu Oct 23 2008 pgajdos@suse.cz
- commented out
  spr-itunes        0/tcp    # Shirt Pocket netTunes
  spl-itunes        0/tcp    # Shirt Pocket launchTunes
  lines [bnc#435600]
* Mon Sep  8 2008 pgajdos@suse.cz
- /etc/services and /etc/protocols was marked as %%config(noreplace)
  [bnc#422884]
* Tue Mar 25 2008 mkoenig@suse.de
- add rpcbind alias for sunrpc [fate#300607]
* Tue Mar  4 2008 pgajdos@suse.cz
- added swat 901/tcp back to the suse.patch [#362590]
* Mon Jan 28 2008 kukuk@suse.de
- Update services file from IANA [bnc#352665]
- Fix PreReqs
* Wed Oct  4 2006 kukuk@suse.de
- Update services file from IANA
* Tue May 23 2006 kukuk@suse.de
- Update protocols and services files from IANA
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Dec 14 2005 kukuk@suse.de
- Update services file
* Mon Sep 12 2005 mmj@suse.de
- Readd the correct services file to patch
* Mon Sep 12 2005 mmj@suse.de
- Add IANA official git port (9418) to services
* Thu Jul  7 2005 kukuk@suse.de
- Update services file
* Tue Mar  8 2005 kukuk@suse.de
- Change comments to make peopleusing file wrongly happy [#71247]
* Wed Feb 23 2005 kukuk@suse.de
- Update /etc/services from IANA
* Tue May 11 2004 mmj@suse.de
- Add example for mlmmj list in /etc/aliases
* Fri Apr 16 2004 kukuk@suse.de
- Add smtps back again, got lost with last update
* Fri Apr  2 2004 kukuk@suse.de
- Use linux.site instead of linux.local [Bug #36949]
* Wed Mar 31 2004 mls@suse.de
- add link-local network
* Mon Mar 29 2004 kukuk@suse.de
- Comment out shilp entry to make reading tcpdump output easier
  [Bug #37359]
* Sun Feb 15 2004 kukuk@suse.de
- Update etc/services file with IANA version
* Mon Dec  1 2003 kukuk@suse.de
- Add etc/netgroup (moved from aaa_base)
* Thu Nov 13 2003 adrian@suse.de
- add registered services to service file
  ( sane, distcc, svn )
* Mon Sep  1 2003 draht@suse.de
- added apcupsd daemons to /etc/hosts.allow (#29646)
* Fri Aug 15 2003 kukuk@suse.de
- Make rpm -V quiet
* Tue May 13 2003 kukuk@suse.de
- Remove inetd.conf, is now part of inetd package
* Thu Apr 24 2003 olh@suse.de
- run tftp via tcpd, not in.tftpd
* Tue Apr 15 2003 ro@suse.de
- change version numbering
* Tue Apr 15 2003 arvin@suse.de
- added pop3s and imaps services to inetd.conf (bug #26281)
* Tue Mar 11 2003 kukuk@suse.de
- Add aaa_base to PreReq. to fix update problems [Bug #25102]
* Thu Feb 13 2003 meissner@suse.de
- Add VNC httpd and 2 VNC display ports, which start Xvnc on demand.
* Mon Jan 27 2003 kukuk@suse.de
- Add etc/ethers [Bug #23016]
* Thu Oct 24 2002 kukuk@suse.de
- etc/services: Add lotusnotes alias to lotusnote [Bug #21145]
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Wed Sep  4 2002 kukuk@suse.de
- etc/services: Add ports for sieve and smtps
* Mon Aug 26 2002 kukuk@suse.de
- etc/services: add mrt entry in temporary area
* Fri Aug 23 2002 kukuk@suse.de
- Fix pop2 daemon name, add imap pop3 daemon [Bug #14474]
* Thu Aug 15 2002 kukuk@suse.de
- Add PreRequires [Bug #17899]
* Sat Aug  3 2002 kukuk@suse.de
- etc/services: add rpcbind alias to sunrpc entry
* Tue Jul 30 2002 kukuk@suse.de
- Fix get_version_number.sh
* Mon Jul 22 2002 adrian@suse.de
- add disabled fam daemon line to inetd.conf
- remove KDE 2 talk daemon lines
  (not anymore support due to security issues)
* Wed Jul 17 2002 kukuk@suse.de
- Remove etc/defaultdomian.rpmnew if empty in postinstall script
* Fri Jul 12 2002 kukuk@suse.de
- Add /etc/aliases as config(noreplace).
* Fri Jul  5 2002 kukuk@suse.de
- Update /etc/services (add new, official ports)
* Tue Jul  2 2002 kukuk@suse.de
- fix typo in /etc/services [Bug #16478]
* Thu Jun 13 2002 draht@suse.de
- removed lprold from the comments in /etc/hosts.allow.
* Thu Jun 13 2002 draht@suse.de
- redo change from Tue Feb  5 18:38:44 MET 2002 - draht@suse.de
  commented out services time, telnet, login, finger from default
  /etc/inetd.conf. No services are configured by default.
* Wed May 15 2002 kssingvo@suse.de
- Add cups-lpd entry to inetd.conf (commented out)
* Wed Mar 13 2002 kukuk@suse.de
- Remove not supported entries [Bug #14932]
* Tue Mar  5 2002 kukuk@suse.de
- Add inofficial entries for pbs to etc/services [Bug #14450]
* Fri Mar  1 2002 kukuk@suse.de
- Add sap db entries back to etc/services
* Wed Feb 13 2002 werner@suse.de
- Add the options '-L sendmail' and '-Am' to be sure that
  sendmail does work as server not as msp client
* Tue Feb  5 2002 draht@suse.de
- revert changes in /etc/inetd.conf
* Tue Feb  5 2002 draht@suse.de
- more descriptive comment in /etc/exports.
* Tue Feb  5 2002 draht@suse.de
- Added users db4web dpbox ingres mail oracle perforce pop sapdb
  squid vscan wnn wwwrun and zope to /etc/ftpusers.
  No users removed, legacy users stay.
* Tue Feb  5 2002 draht@suse.de
- commented out services telnet, login and finger from default
  /etc/inetd.conf file.
* Tue Feb  5 2002 draht@suse.de
- add list of wrapped services and examples to /etc/hosts.allow
- changed comment on /etc/hosts.deny
* Tue Feb  5 2002 kukuk@suse.de
- Fix x11 entry in etc/services
* Fri Feb  1 2002 draht@suse.de
- removed ^m characters from etc/services
* Tue Jan 22 2002 kukuk@suse.de
- Sync protocols with official list [Bug #12870]
- Sync services with official list
* Fri Jan 18 2002 kukuk@suse.de
- disable talk, not in wide use today
- amindexd and amidxtaped should run as user amanda [Bug #12619]
* Wed Jan 16 2002 ro@suse.de
- fixed filelist
* Wed Jan 16 2002 kukuk@suse.de
- Remove /var/adm/setup, diphost and add defaultdomain and HOSTNAME
* Mon Oct 22 2001 mmj@suse.de
- Change inetd.conf to have vsftpd support
* Mon Jul 30 2001 kukuk@suse.de
- Fix typo in hosts.equiv [Bug #9420]
* Tue Jul 10 2001 kukuk@suse.de
- Change inetd.conf entry for tftp to match new version
* Fri Jul  6 2001 kukuk@suse.de
- Fix path to initscript in comment
* Tue Jun  5 2001 kukuk@suse.de
- services: Add ksysguard
* Wed May  9 2001 kukuk@suse.de
- Don't send wrong email about changed ftp server
- Fix english comment in inetd.conf [Bug #7913]
* Mon Apr 30 2001 ro@suse.de
- added sql6 as 7210/tcp to etc/services
* Fri Apr 20 2001 kukuk@suse.de
- Add comments for use of ktalkd [Bug #6566]
* Wed Apr 11 2001 kukuk@suse.de
- Revert some of the last changes [Bug #6957]
* Mon Mar 26 2001 kukuk@suse.de
- Update etc/protocols from official iana list [Bug #4183]
* Sat Mar 24 2001 kukuk@suse.de
- etc/services: Add canna entry
* Thu Mar 22 2001 kukuk@suse.de
- Fix example in hosts.allow
- etc/inetd.conf: Only enable time, telnet, rlogin and talk.
* Fri Feb  9 2001 schwab@suse.de
- Fix cvs pserver example (#6293).
* Thu Dec 14 2000 ro@suse.de
- removed lines db2cdb2inst1 and db2idb2inst1 from etc/services (#4461)
* Sat Nov 18 2000 kukuk@suse.de
- Add dqs entries for nashif@suse.de
* Wed Sep 27 2000 kukuk@suse.de
- Add more Wnn* entries to etc/services
* Fri Jul 28 2000 kukuk@suse.de
- Fix rsync example
* Mon Jun 19 2000 kukuk@suse.de
- Compress tar archive
* Mon Jun 19 2000 kukuk@suse.de
- Enable swat in etc/inetd.conf
* Fri May 26 2000 kukuk@suse.de
- Fix tar archive
* Thu May 25 2000 kukuk@suse.de
- Add etc/host.conf
* Mon May 15 2000 kukuk@suse.de
- Remove ypserv entries from hosts.allow/hosts.deny
* Mon May 15 2000 ro@suse.de
- removed duplicate line for opalis-rdv
* Mon May 15 2000 kukuk@suse.de
- etc/services: Add procstatd entry
- etc/inetd.conf: Likewise.
* Tue May  9 2000 ro@suse.de
- added services entry for codine_commd
  (inofficial 536/tcp)
* Mon Apr 17 2000 kukuk@suse.de
- etc/inetd.conf: Change tftpd default configuration to make a
  chroot into tftpboot directory
* Wed Apr  5 2000 kukuk@suse.de
- etc/services: Add more entries
* Wed Apr  5 2000 kukuk@suse.de
- etc/inetd.conf: service name is imap, not imap2 [Bug 2607]
* Mon Mar 13 2000 kukuk@suse.de
- etc/services: Now really fix axnet entry [Bug 2080]
* Fri Feb 25 2000 garloff@suse.de
- cvs entry fixed: path to cvs added.
* Fri Feb 25 2000 kukuk@suse.de
- etc/services: Add more entries [Bug 2080]
* Sun Feb 20 2000 garloff@suse.de
- added commented entry for cvs-pserver to inet.conf
* Wed Feb 16 2000 kukuk@suse.de
- etc/services: Add pbs entries
* Tue Feb 15 2000 kukuk@suse.de
- etc/inetd.conf: fix some typos
* Thu Jan 20 2000 kukuk@suse.de
- Add missing amanda client entry to etc/inetd.conf
* Wed Jan 19 2000 kukuk@suse.de
- Add missing amanda idx entries to etc/services
* Thu Jan 13 2000 kukuk@suse.de
- etc/ftpusers: Add more systemuser from /etc/passwd
* Thu Jan 13 2000 kukuk@suse.de
- Add IPv6 addresses to etc/hosts
* Tue Jan 11 2000 kukuk@suse.de
- etc/services: Add db2 and http-rman entries
* Mon Jan  3 2000 kukuk@suse.de
- etc/inetd.conf: Remove RPC entries
- etc/protocols: Add IPv6
- etc/services: Add all known services
- etc/rpc: Removed, is in shlibs
* Thu Oct 21 1999 kukuk@suse.de
- etc/inetd.conf: fix comments, disable btx and rplay
- etc/ftpusers: Add more system users
- etc/services: Add more official assinged numbers
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Sat Sep 11 1999 kukuk@suse.de
- Make in.ftpd default ftp daemon (fixes bug #268)
* Thu Sep  2 1999 kukuk@suse.de
- Don't start identd from inetd
* Mon Jul 12 1999 bs@suse.de
- fixed buglet in %%post (create var/adm/notify/messages)
* Mon Jul 12 1999 ro@suse.de
- updated etc/services (added https, ftp, data)
* Tue May 25 1999 uli@suse.de
- added services/inetd.conf entries for Mimer
* Tue Mar 30 1999 bs@suse.de
- enabled time services in /etc/inetd.conf
* Mon Mar 22 1999 bs@suse.de
- added "bin" and "daemon" to /etc/ftpusers
* Tue Mar  9 1999 ro@suse.de
- /etc/services: added entries for IBM DB2 Database
* Tue Mar  2 1999 ro@suse.de
- glibc is libc.so.6.1 on alpha: no etc/rpc there
* Wed Jan 13 1999 bs@suse.de
- added some entries for samba to inetd.conf and services
* Sat Dec  5 1998 bs@suse.de
- added netplan to /etc/services
- marked /etc/inetd.conf as noreplace
* Sat Nov 28 1998 bs@suse.de
- added rsync to etc/services and etc/inetd.conf
* Wed Nov 18 1998 bs@suse.de
- disabled vbox in inetd.conf
* Tue Nov 17 1998 bs@suse.de
- hosts.equiv: typo fix
- etc/services:  added afpovertcp, mysql
- etc/inetd.conf:  added leafnode, vboxd
    removed in.nntpd
* Fri Aug 21 1998 bs@suse.de
- added some entries to /etc/services to be friendly for netatalk
* Mon Aug 17 1998 bs@suse.de
- changed entry for rplayd in inetd.conf
* Tue Jul 28 1998 bs@suse.de
- changed comment headers in /etc/hosts and /etc/hosts.lpd
- added "noreplace" feature.
* Mon Jul 13 1998 bs@suse.de
- inetd.conf
  - added new entry for rplay
  - added entry for proftpd
- services:
  - added aliases for imap2 (imap, imap4)
* Thu May 28 1998 bs@suse.de
- disabled imap2 in /etc/inetd.conf
* Tue Mar  3 1998 ro@suse.de
- etc/services     - changed entry for http-rman to nowait.10000
* Sat Feb 28 1998 ro@suse.de
- etc/services     - added entried for radius
* Mon Feb  9 1998 bs@suse.de
- etc/services:    - added entries for amanda
  - added entries for ssh
- etc/inetd.conf:  - added entries for amanda
  - added "-e" to /usr/sbin/in.identd
  - added comment for "keep-alive"
* Wed Jan 28 1998 ro@suse.de
- changed ftpd from in.ftpd to wu.ftpd in /etc/inetd.conf
  (in case of update with existing in.ftpd and nonexisting
  wu.ftpd, the administrator is notified of the change)
* Mon Jan 26 1998 ro@suse.de
- added entries for hp eloquence software 8010,8100,8102,8104
